@@ -51,7 +51,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "3.7.9"
+__version__ = "3.7.11"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_BME680.git"
 
 
@@ -385,10 +385,13 @@ class Adafruit_BME680:
         ctrl = (ctrl & 0xFC) | 0x01  # enable single shot!
         self._write(_BME680_REG_CTRL_MEAS, [ctrl])
         new_data = False
+        start_time = time.monotonic()
         while not new_data:
             data = self._read(_BME680_REG_MEAS_STATUS, 17)
             new_data = data[0] & 0x80 != 0
             time.sleep(0.005)
+            if time.monotonic() - start_time >= 3.0:
+                raise RuntimeError("Timeout while reading sensor data")
         self._last_reading = time.monotonic()
 
         self._adc_pres = _read24(data[2:5]) / 16
